BuiltModel

Struct BuiltModel 

pub struct BuiltModel<M> { /* private fields */ }
Compiled formula artifact.

Implementations

Source

impl<M> BuiltModel<M>

pub fn model(&self) -> &M

Returns the compiled core model.

pub fn model_mut(&mut self) -> &mut M

Returns the compiled core model mutably.

pub fn into_model(self) -> M

Consumes the artifact and returns the compiled core model.

pub fn schema(&self) -> &ModelSchema

Returns formula schema metadata.

pub fn terms(&self) -> &[ParameterTerms]

Returns fitted terms grouped by distribution parameter.

pub fn terms_for(&self, parameter: &str) -> Option<&[FittedTerm]>

Returns fitted terms for one distribution parameter.

pub fn coefficient_names(&self) -> Vec<&str>

Returns coefficient names in model layout order.

pub fn layout(&self) -> &ParameterLayout

Returns core parameter layout.

Source

impl<'a> BuiltModel<CompiledNormal<'a>>

pub fn prediction_blocks<D>( &self, data: &D, ) -> Result<NormalBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<NormalBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<NormalBlocks>, ) -> Result<Vec<<DefaultNormal as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultNormal as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.

Source

impl<'a> BuiltModel<CompiledGamma<'a>>

pub fn prediction_blocks<D>( &self, data: &D, ) -> Result<GammaBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<GammaBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<GammaBlocks>, ) -> Result<Vec<<DefaultGamma as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultGamma as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.

Source

impl<'a> BuiltModel<CompiledLogNormal<'a>>

pub fn prediction_blocks<D>( &self, data: &D, ) -> Result<LogNormalBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<LogNormalBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<LogNormalBlocks>, ) -> Result<Vec<<DefaultLogNormal as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultLogNormal as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.

Source

impl<'a> BuiltModel<CompiledWeibull<'a>>

pub fn prediction_blocks<D>( &self, data: &D, ) -> Result<WeibullBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<WeibullBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<WeibullBlocks>, ) -> Result<Vec<<DefaultWeibull as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultWeibull as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.

Source

impl<'a> BuiltModel<CompiledInverseGaussian<'a>>

pub fn prediction_blocks<D>( &self, data: &D, ) -> Result<InverseGaussianBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<InverseGaussianBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<InverseGaussianBlocks>, ) -> Result<Vec<<DefaultInverseGaussian as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultInverseGaussian as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.

Source

impl<'a> BuiltModel<CompiledBeta<'a>>

pub fn prediction_blocks<D>(&self, data: &D) -> Result<BetaBlocks, FormulaError>
where D: DataView + ?Sized,

Rebuilds compatible typed prediction blocks from fitted term metadata.

pub fn prediction_design<D>( &self, data: &D, ) -> Result<PredictionDesign<BetaBlocks>, FormulaError>
where D: DataView + ?Sized,

Builds reusable prediction design from fitted term metadata.

pub fn predict_theta_with_design( &self, theta: &[f64], design: &PredictionDesign<BetaBlocks>, ) -> Result<Vec<<DefaultBeta as Family>::Theta>, FormulaError>

Predicts natural-scale distribution parameters with reusable prediction design.

pub fn predict_theta<D>( &self, theta: &[f64], data: &D, ) -> Result<Vec<<DefaultBeta as Family>::Theta>, FormulaError>
where D: DataView + ?Sized,

Predicts natural-scale distribution parameters for new rows.