pub struct TensorPSplineTerm { /* private fields */ }Expand description
Tensor-product P-spline term options.
Implementations
Sourceimpl TensorPSplineTerm
impl TensorPSplineTerm
Sourcepub fn k(self, left: usize, right: usize) -> Self
pub fn k(self, left: usize, right: usize) -> Self
Sets basis counts for the left and right axes.
Sourcepub fn order(self, left: SplineOrder, right: SplineOrder) -> Self
pub fn order(self, left: SplineOrder, right: SplineOrder) -> Self
Sets spline orders for the left and right axes.